@@ -4,8 +4,8 @@ function varargout = base64encode(varargin)
 %
 % Encoding a binary vector or array using Base64
 %
-% This function depends on JVM in MATLAB or, can optionally use the ZMat 
-% toolbox (http://github.com/fangq/zmat)
+% This function depends on JVM in MATLAB or, can optionally use the ZMat
+% toolbox (http://github.com/NeuroJSON/zmat)
 %
 % Copyright (c) 2012, Kota Yamaguchi
 % URL: https://www.mathworks.com/matlabcentral/fileexchange/39526-byte-encoding-utilities
@@ -23,29 +23,29 @@ function varargout = base64encode(varargin)
 %      orig=char(base64decode(bytes))
 %
 % license:
-%     BSD or GPL version 3, see LICENSE_{BSD,GPLv3}.txt files for details 
+%     BSD or GPL version 3, see LICENSE_{BSD,GPLv3}.txt files for details
 %
 % -- this function is part of JSONLab toolbox (http://iso2mesh.sf.net/cgi-bin/index.cgi?jsonlab)
 %
 
-if(nargin==0)
+if (nargin == 0)
     error('you must provide at least 1 input');
 end
 
-if(exist('zmat','file')==2 || exist('zmat','file')==3)
-    [varargout{1:nargout}]=zmat(varargin{1}, 1,'base64',varargin{2:end});
-    return;
+if (exist('zmat', 'file') == 2 || exist('zmat', 'file') == 3)
+    [varargout{1:nargout}] = zmat(varargin{1}, 1, 'base64', varargin{2:end});
+    return
 end
 
-if(ischar(varargin{1}))
-    varargin{1}=uint8(varargin{1});
+if (ischar(varargin{1}))
+    varargin{1} = uint8(varargin{1});
 end
 
-input=typecast(varargin{1}(:)','uint8');
+input = typecast(varargin{1}(:)', 'uint8');
 
-if(isoctavemesh)
+if (isoctavemesh)
     varargout{1} = base64_encode(uint8(input));
-    return;
+    return
 end
 
 error(javachk('jvm'));
@@ -54,4 +54,4 @@ if ischar(input)
 end
 
 varargout{1}  = char(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(input))';
-varargout{1}  = regexprep(varargout{1} ,'\r','');
+varargout{1}  = regexprep(varargout{1}, '[\r\n]', '');
