@@ -6,7 +6,7 @@ function varargout = lzipencode(varargin)
 %
 % Compress a string or a numerical array using LZip-compression
 %
-% This function depends on the ZMat toolbox (http://github.com/fangq/zmat)
+% This function depends on the ZMat toolbox (http://github.com/NeuroJSON/zmat)
 %
 % authors:Qianqian Fang (q.fang <at> neu.edu)
 %
@@ -22,18 +22,18 @@ function varargout = lzipencode(varargin)
 %      orig=lzipdecode(bytes,info);
 %
 % license:
-%     BSD or GPL version 3, see LICENSE_{BSD,GPLv3}.txt files for details 
+%     BSD or GPL version 3, see LICENSE_{BSD,GPLv3}.txt files for details
 %
 % -- this function is part of JSONLab toolbox (http://iso2mesh.sf.net/cgi-bin/index.cgi?jsonlab)
 %
 
-if(nargin==0)
+if (nargin == 0)
     error('you must provide at least 1 input');
 end
 
-if(exist('zmat','file')==2 || exist('zmat','file')==3)
-    [varargout{1:nargout}]=zmat(varargin{1}, 1,'lzip',varargin{2:end});
-    return;
+if (exist('zmat', 'file') == 2 || exist('zmat', 'file') == 3)
+    [varargout{1:nargout}] = zmat(varargin{1}, 1, 'lzip', varargin{2:end});
+    return
 else
-    error('you must install ZMat toolbox to use this feature: http://github.com/fangq/zmat')
+    error('you must install ZMat toolbox to use this feature: http://github.com/NeuroJSON/zmat');
 end
